#
# spec file for package maven-plugin-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name maven-plugin-tools
Name:           maven-plugin-plugin
Version:        3.9.0
Release:        1.2
Summary:        Maven Plugin Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugin-tools/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugin-tools/%{base_name}/%{version}/%{base_name}-%{version}-source-release.zip
Patch0:         0002-Remove-dependency-on-jtidy.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-annotations)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-ant)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-api)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-beanshell)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-generators)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-tools-java)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-repository-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-velocity)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
Obsoletes:      %{name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
BuildArch:      noarch

%description
The Plugin Plugin is used to create a Maven plugin descriptor for any Mojo's
found in the source tree, to include in the JAR. It is also used to generate
Xdoc files for the Mojos as well as for updating the plugin registry, the
artifact metadata and a generic help goal.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{base_name}-%{version}
%patch0 -p1

%pom_remove_plugin -r :maven-enforcer-plugin

%pom_xpath_inject "pom:project/pom:properties" "
    <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
    <project.reporting.outputEncoding>UTF-8</project.reporting.outputEncoding>"

# Remove test dependencies because tests are skipped anyways.
%pom_xpath_remove "pom:dependency[pom:scope='test']"

%pom_remove_dep org.junit:junit-bom
%pom_remove_dep :maven-plugin-tools-ant maven-plugin-plugin
%pom_remove_dep :maven-plugin-tools-beanshell maven-plugin-plugin

%build
pushd %{name}
%{mvn_file} :%{name} %{base_name}/%{name}
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

popd

%install
pushd %{name}
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}
popd

%files -f %{name}/.mfiles
%license LICENSE NOTICE

%files javadoc -f %{name}/.mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Fri Sep 22 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.9.0
- Changes of version 3.9.0
  * Bug
    + MPLUGIN-470: *-mojo.xml (in PluginXdocGenerator) is
    overwritten when multiple locales are defined
    + MPLUGIN-471: Generated table by PluginXdocGenerator does not
    contain default attributes
  * Improvement
    + MPLUGIN-469: Omit empty line in generated help goal output if
    plugin description is empty
    + MPLUGIN-472: Use Plexus I18N rather than fiddling with
  * Task
    + MPLUGIN-467: Remove reporting from maven-plugin-plugin: create
    maven-plugin-report-plugin
  * Dependency upgrade
    + MPLUGIN-468: Upgrade plugins and components (in ITs)
- Changes of version 3.8.2
  * Improvement
    + MPLUGIN-457: Use Resolver API, get rid of localRepository
  * Dependency upgrade
    + MPLUGIN-458: Bump httpcore from 4.4.15 to 4.4.16
    + MPLUGIN-459: Bump httpclient from 4.5.13 to 4.5.14
    + MPLUGIN-460: Bump antVersion from 1.10.12 to 1.10.13
    + MPLUGIN-461: Bump slf4jVersion from 1.7.5 to 1.7.36
    + MPLUGIN-462: Bump plexus-java from 1.1.1 to 1.1.2
    + MPLUGIN-463: Bump plexus-archiver from 4.6.1 to 4.6.3
    + MPLUGIN-464: Bump jsoup from 1.15.3 to 1.15.4
    + MPLUGIN-465: Bump asmVersion from 9.4 to 9.5
    + MPLUGIN-466: Bump assertj-core from 3.23.1 to 3.24.2
- Changes of version 3.8.1
  * Bug
    + MPLUGIN-443: Javadoc reference containing a link label with
    spaces are not detected
    + MPLUGIN-444: JavadocLinkGenerator.createLink: Support nested
    binary class names
    + MPLUGIN-446: ERROR during build of m-plugin-report-p and
    m-plugin-p: Dependencies in wrong scope
    + MPLUGIN-448: "Executes as an aggregator plugin" documentation:
    s/plugin/goal/
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
    + MPLUGIN-453: Fix Temporary File Information Disclosure
    Vulnerability
  * New Feature
    + MPLUGIN-441: Support mojos using the new maven v4 api
  * Improvement
    + MPLUGIN-425: Plugin descriptor should contain the
    requiredJavaVersion/requiredMavenVersion
    + MPLUGIN-439: Execute annotation only supports standard
    lifecycle phases due to use of enum
    + MPLUGIN-440: Clarify deprecation of all extractors but the
    maven-plugin-tools-annotations
  * Dependency upgrade
    + MPLUGIN-447: Update to Maven Parent POM 39
    + MPLUGIN-454: Bump junit-bom from 5.9.1 to 5.9.2
    + MPLUGIN-455: Bump plexus-archiver from 4.5.0 to 4.6.1
- Changes of version 3.7.1
  * Bug
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
- Changes of version 3.7.0
  * Bug
    + MPLUGIN-298: The plugin descriptor generated by
    plugin:descriptor does not consider @ see javadoc taglets
    + MPLUGIN-394: Report-Mojo doesn't respect input encoding
    + MPLUGIN-403: Generating site reports for plugin results in
    NoSuchMethodError
    + MPLUGIN-404: JDK Requirements in plugin-info.html: Consider
    property "maven.compiler.release"
    + MPLUGIN-420: Parameters documentation inheriting @ since from
    Mojo can be confusing
    + MPLUGIN-428: Don't emit warning for missing javadoc URL of
    primitives
    + MPLUGIN-429: Don't emit warning for missing javadoc URI if no
    javadoc sources are configured
    + MPLUGIN-438: Parameter description should be taken from
    annotated item
  * New Feature
    + MPLUGIN-9: Add link to javadoc in configuration description
    page for user defined types of Mojos.
    + MPLUGIN-396: Allow only @ Deprecated annotation without @
    deprecated javadoc tag
    + MPLUGIN-400: add system requirements history section
    + MPLUGIN-402: report: allow to generate usage section in
    plugin-info.html with true
    + MPLUGIN-419: Allow @ Parameter on setters methods
    + MPLUGIN-423: Extract plugin report into its own plugin
    + MPLUGIN-427: report: Expose generics information of Collection
    and Map types
  * Improvement
    + MPLUGIN-297: plugin-info.html should contain a better Usage
    section
    + MPLUGIN-390: Do not overwrite generate files with no content
    change
    + MPLUGIN-393: Upgrade to JUnit 5 and @ Inject annotations
    + MPLUGIN-398: Support for java 20 - ASM 9.4
    + MPLUGIN-405: Don't print empty Memory, Disk Space in System
    Requirements
    + MPLUGIN-408: simplification in helpmojo build
    + MPLUGIN-411: Get rid of plexus-compiler-manager from tests
    + MPLUGIN-412: Use Maven core artifacts in provided scope
    + MPLUGIN-417: report and descriptor goal need to evaluate
    Javadoc comments differently
    + MPLUGIN-433: Allow to reference aggregator javadoc from plugin
    report
  * Task
    + MPLUGIN-378: Detect legacy/javadoc Mojo definitions, warn to
    use Java 5 annotations
    + MPLUGIN-389: Update level to Java 8
    + MPLUGIN-391: Deprecate scripting support for mojos
    + MPLUGIN-406: Deprecate requirements parameter in report Mojo
    + MPLUGIN-407: Remove duplicate code from PluginReport
    + MPLUGIN-409: Prepare for Doxia (Sitetools) 2.0.0
    + MPLUGIN-430: Fix documentation for maven-plugin-report-plugin
    + MPLUGIN-431: Remove deprecated items from new
    maven-plugin-report-plugin
    + MPLUGIN-432: Improve site build
    + MPLUGIN-434: Improve dependency management
    + MPLUGIN-437: Plugin generator generation fails when the parent
    class comes from a different project
  * Dependency upgrade
    + MPLUGIN-395: Upgrade Maven Reporting API/Impl to 3.1.0
    + MPLUGIN-397: Upgrade Parent to 36
    + MPLUGIN-399: Upgrade project dependencies after JDK 1.8
    + MPLUGIN-413: Bump maven-parent from 36 to 37
    + MPLUGIN-415: Upgrade Maven Reporting API to 3.1.1/Maven
    Reporting Impl to 3.2.0
    + MPLUGIN-422: Upgrade plexus-utils to 3.5.0
- Changes of version 3.6.4
  * What's Changed
    + MPLUGIN-384: restore compatibility with Maven 3 ecosystem
    + MPLUGIN-387: Upgrade dependencies
- Changes of version 3.6.3
  * What's Changed
    + MPLUGIN-383: add prerequisites to plugin pom
    + MPLUGIN-382: exclude dependency in provided scope from plugin
    descriptor
    + Get rid of String.format use
    + Fix this logging as well
    + (doc) Simplify documentation
    + MPLUGIN-386: Exclude maven-archiver and maven-jxr from warning
- Changes of version 3.6.2
  * What's Changed
    + MPLUGIN-374: deprecate unused requiresReports flag
    + MPLUGIN-370: Check that Maven dependencies are provided scope
    + Update ITs
    + use shared gh action
    + MPLUGIN-375: deprecate unsupported Mojo descriptor items
    + Weed out ITs
    + MPLUGIN-377: Upgrade to maven 3.x and avoid using deprecated
    API
    + MPLUGIN-376: Drop legacy dependencies
    + use shared gh action - v1
    + fix wording in javadoc
- Changes of version 3.6.1
  * What's Changed
    + Add missing @OverRide and make methods static
    + MPLUGIN-355: Upgrade to JUnit 4.12
    + upgrade parent POM and other dependencies
    + deps: update plugins
    + MPLUGIN-359: upgrade Doxia Sitetools to 1.9.2 to remove
    dependency on Struts
    + MNGSITE-393: remove Maven 2 info
    + remove unneeded dependency
    + tighten the dependency tree
    + ignore .checkstyle
    + strict dependencies for maven-plugin-tools-annotations
    + (doc) added "help" goal; goal number corrected
    + MPLUGIN-368: Improve @execute(goal...) docs
    + MPLUGIN-367: Improve @execute(lifecycle...) docs
- Modified patches:
  * maven-plugin-plugin-bootstrap-resouces.patch
  * regenerate in cycle
  * 0004-Remove-dependency-on-jtidy.patch
  - > 0002-Remove-dependency-on-jtidy.patch
  * regenerate to changed context
- Removed patches:
  * 0001-Avoid-duplicate-MOJO-parameters.patch
  * 0002-Deal-with-nulls-from-getComment.patch
  * 0003-Port-to-plexus-utils-3.0.24.patch
    + not needed with this version
* Sun Sep  3 2023 Fridrich Strba <fstrba@suse.com>
- Download sources from https://repo1.maven.org
* Mon Jul 24 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0004-Remove-dependency-on-jtidy.patch
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream 3.6.0
  * allow building with java > 1.8 too against objectweb-asm 7.2
- Removed patch:
  * fix-getPluginsAsMap.patch
    + fix is present in the updated sources
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Wed Apr  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of the non-bootstrap version of
  maven-plugin-plugin 3.5.1
